# TMA - Tools for Market A - A股工具集

> 专为中国A股设计开发的工具集，着重点是交易数据获取和分析。我是一只菜鸟，对A股
的认识非常肤浅，如果你愿意用积攒的经验为我开发这套工具
提供一些帮助，请联系`zeng_bin8888@163.com`，不胜感激！

## 快速入门


### 安装、卸载、更新
* 安装 - `pip install tma`
* 卸载 - `pip uninstall tma`
* 更新 - `pip install --upgrade tma`

### 基于 TFIDF 的文档排序模型

```python
from tma.collector import xhn
from tma.analyst import rank

# 采集新华网今日首页头条文章
hp = xhn.HomePage()
articles = hp.get_articles()
news = [x['title'] + '|' + x['source'] + "|" +
        x['content'] for x in articles]
news = [x.replace('\n', "") for x in news]

# 使用TFIDF排序模型
ranker = rank.TfidfDocRank(news, N=20)
# 查看前30条排序结果
print(ranker.top30)
# 查看前3条排序结果
ranker.rank(top=3)
```

### 基于 TextRank 的新闻联播自动摘要抽取

新闻联播数据来自 [Tushare Pro](https://tushare.pro/)，
[点击注册](https://tushare.pro/register?reg=7)，在【个人主页】可以查看接口token。

```python
# 首先设置 tushare pro 的接口token
# 如果之前已经使用过 tushare pro，并且设置过接口token，可以省略这一步
import tushare as ts
ts.set_token("**************************")

from tma.analyst.news import cctv_abstract

abstract = cctv_abstract(date='20181124')
print(abstract)
```

```
(1) 22日，在国家主席习近平对西班牙进行国事访问前夕，由中国国务院新闻办公室等主办的《习近平谈治国理政》中西读者会、中国改革开放40周年暨经济发展研讨会在西班牙马德里举行。
(2) 委员长会议组成人员认为，习近平总书记的重要讲话深刻阐述了发展新一代人工智能的重要意义、核心问题、关键举措，并专门就人工智能相关法律问题作出指示，不仅为新时代科技创新和人工智能发展指明了方向、作出了部署，也对人大及其常委会助推我国新一代人工智能健康发展提出了具体要求。
(3) 山西省作为全国最大的焦炭生产基地，为了实现协同推动经济高质量发展和生态环境高水平保护，当地以环保倒逼，加速传统产业转型升级。
(4) 胡安所说的改变源于四年前，“义新欧”班列开通了9条国际线路，其中，义乌至西班牙马德里的班列是世界上运输线路最长的国际班列，沿途经过的许多国家给胡安的事业带来了新的商机，同时，“义新欧”班列的开通也吸引着越来越多的外商来到义乌。
(5) “广西生态优势金不换”，党的十八大以来，广西综合施策，通过河道治理、截污治污、河道补水、海绵城市建设等，持续改善水环境，目前国控断面优良率保持在96.2%以上，让居民在家门口就能收获幸福感。
(6) 中欧班列开通后，他可以采购的不仅仅有中国商品，还有这些云集义乌，来自100多个国家和地区的十万多种国际特色商品。
(7) 全国人大及其常委会的立法、监督等工作，也要围绕实现这一目标谋划和推进，推动完善科技体制机制，助力攻克关键核心技术，促进科技成果加快转化应用，推动建设一流科技人才队伍，着力提升人工智能等领域的自主创新能力，强化科技创新的战略支撑作用。
(8) 要立足于自主创新，准确把握世界科技发展大势，直面问题、迎难而上，推动我国科技和产业实现跨越发展。
(9) 四年间，义乌铁路口岸实行一体化通关，“义新欧”班列在沿线设立了5个物流分拨点、8个海外仓，还推进了“一带一路”捷克站、华沙中国小商品城市场和中白工业园区等项目建设。
(10) 全国人大常委会委员长会议组成人员24日进行专题学习，学习习近平总书记在中央政治局第九次集体学习时的重要讲话，围绕人大立法监督工作保障和规范人工智能发展进行学习讨论，栗战书委员长主持并讲话。
```